@@ -446,11 +446,11 @@ def prepare_runtime_extensions_package_release() -> None:
     print("---------------- Preparing Individual Packages ------------------")
     print("-----------------------------------------------------------------")
 
-    packages = {'kfp-notebook':['kfp>=1.6.3'],
-                'airflow-notebook':['pygithub', 'black']}
+    packages = {'kfp-notebook': ['kfp>=1.6.3'],
+                'airflow-notebook': ['pygithub', 'black']}
 
-    packages_source = {'kfp-notebook':'kfp',
-                      'airflow-notebook':'airflow'}
+    packages_source = {'kfp-notebook': 'kfp',
+                       'airflow-notebook': 'airflow'}
 
     for package in packages:
         package_source_dir = os.path.join(config.work_dir, package)
@@ -608,7 +608,7 @@ def initialize_config(args=None) -> SimpleNamespace:
 
     configuration = {
         'goal': args.goal,
-        'git_branch': 'v3.1.x',
+        'git_branch': "v3.2.x",
         'git_url': DEFAULT_GIT_URL,
         'git_extension_package_url': DEFAULT_EXTENSION_PACKAGE_GIT_URL,
         'git_hash': 'HEAD',
@@ -654,6 +654,8 @@ def print_config() -> None:
         print(f'RC number \t\t -> {config.rc}')
     if config.beta is not None:
         print(f'Beta number \t\t -> {config.beta}')
+    if config.git_branch is not None:
+        print(f'Branch \t\t\t -> {config.git_branch}')
     print(f'Dev Version \t\t -> {config.dev_version}')
     print(f'Dev NPM Version \t -> {config.dev_npm_version}')
     print(f'Release Tag \t\t -> {config.tag}')
